# spooky_go

Rust and Python library for the game of Go.

# Rust

```fish
cargo add spooky_go
```

# Python

```fish
uv add spooky-go
```

## Develop

### Tests

- `fish run_tests.fish`
    - `fish run_python_tests.fish`
    - `fish run_rust_tests.fish`

### Lints

- `fish run_lints.fish`
